# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import blobstorage_vdisk_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__vdisk__config__pb2
from ydb.core.protos import blobstorage_pdisk_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pdisk__config__pb2
from ydb.core.protos import blobstorage_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__config__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/blobstorage.proto\x12\x12NKikimrBlobStorage\x1a&library/cpp/actors/protos/actors.proto\x1a,library/cpp/actors/protos/interconnect.proto\x1a\x1aydb/core/protos/base.proto\x1a.ydb/core/protos/blobstorage_vdisk_config.proto\x1a.ydb/core/protos/blobstorage_pdisk_config.proto\x1a(ydb/core/protos/blobstorage_config.proto\x1a&ydb/core/protos/blobstorage_disk.proto\x1a,ydb/core/protos/blobstorage_disk_color.proto\"/\n\nTMessageId\x12\x12\n\nSequenceId\x18\x01 \x01(\x04\x12\r\n\x05MsgId\x18\x02 \x01(\x04\"\xa4\x01\n\x12TVDiskCostSettings\x12\x12\n\nSeekTimeUs\x18\x01 \x01(\x04\x12\x14\n\x0cReadSpeedBps\x18\x02 \x01(\x04\x12\x15\n\rWriteSpeedBps\x18\x03 \x01(\x04\x12\x15\n\rReadBlockSize\x18\x04 \x01(\x04\x12\x16\n\x0eWriteBlockSize\x18\x05 \x01(\x04\x12\x1e\n\x16MinREALHugeBlobInBytes\x18\x06 \x01(\r\"\xe0\x02\n\x0fTWindowFeedback\x12;\n\x06Status\x18\x01 \x01(\x0e\x32+.NKikimrBlobStorage.TWindowFeedback.EStatus\x12\x18\n\x10\x41\x63tualWindowSize\x18\x02 \x01(\x04\x12\x15\n\rMaxWindowSize\x18\x03 \x01(\x04\x12\x35\n\rExpectedMsgId\x18\x04 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TMessageId\x12\x33\n\x0b\x46\x61iledMsgId\x18\x05 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TMessageId\"s\n\x07\x45Status\x12\x0b\n\x07Unknown\x10\x00\x12\x0b\n\x07Success\x10\x01\x12\x10\n\x0cWindowUpdate\x10\x02\x12\r\n\tProcessed\x10\x03\x12\x12\n\x0eIncorrectMsgId\x10\x04\x12\x19\n\x15HighWatermarkOverflow\x10\x05\"\xa5\x01\n\x0eTExecTimeStats\x12\x17\n\x0fSubmitTimestamp\x18\x01 \x01(\x04\x12\x15\n\rInSenderQueue\x18\x02 \x01(\x04\x12\x19\n\x11ReceivedTimestamp\x18\x03 \x01(\x04\x12\r\n\x05Total\x18\x04 \x01(\x04\x12\x0f\n\x07InQueue\x18\x05 \x01(\x04\x12\x11\n\tExecution\x18\x06 \x01(\x04\x12\x15\n\rHugeWriteTime\x18\x07 \x01(\x04\"\xb8\x04\n\x07TMsgQoS\x12\x17\n\x0f\x44\x65\x61\x64lineSeconds\x18\x01 \x01(\r\x12-\n\x05MsgId\x18\x02 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TMessageId\x12\x0c\n\x04\x43ost\x18\x03 \x01(\x04\x12\x35\n\nExtQueueId\x18\x05 \x01(\x0e\x32!.NKikimrBlobStorage.EVDiskQueueId\x12=\n\nIntQueueId\x18\x06 \x01(\x0e\x32).NKikimrBlobStorage.EVDiskInternalQueueId\x12<\n\x0c\x43ostSettings\x18\x07 \x01(\x0b\x32&.NKikimrBlobStorage.TVDiskCostSettings\x12\x1a\n\x12SendMeCostSettings\x18\x08 \x01(\x08\x12\x33\n\x06Window\x18\t \x01(\x0b\x32#.NKikimrBlobStorage.TWindowFeedback\x12\x15\n\x0bProxyNodeId\x18\n \x01(\rH\x00\x12\x15\n\x0bReplVDiskId\x18\x0b \x01(\rH\x00\x12\x15\n\x0bVDiskLoadId\x18\r \x01(\x04H\x00\x12\x17\n\rVPatchVDiskId\x18\x0e \x01(\rH\x00\x12\x39\n\rExecTimeStats\x18\x0c \x01(\x0b\x32\".NKikimrBlobStorage.TExecTimeStats\x12-\n\rSenderActorId\x18\x0f \x01(\x0b\x32\x16.NActorsProto.TActorIdB\n\n\x08\x43lientId\"\x98\x01\n\x10TEvVWindowChange\x12\x37\n\x0c\x46rontQueueId\x18\x01 \x01(\x0e\x32!.NKikimrBlobStorage.EVDiskQueueId\x12\x33\n\x06Window\x18\x02 \x01(\x0b\x32#.NKikimrBlobStorage.TWindowFeedback\x12\x16\n\x0e\x44ropConnection\x18\x03 \x01(\x08\"\x81\x01\n\x0bTTimestamps\x12\x1a\n\x0fSentByDSProxyUs\x18\x01 \x01(\x04:\x01\x30\x12\x1c\n\x11ReceivedByVDiskUs\x18\x02 \x01(\x04:\x01\x30\x12\x18\n\rSentByVDiskUs\x18\x03 \x01(\x04:\x01\x30\x12\x1e\n\x13ReceivedByDSProxyUs\x18\x04 \x01(\x04:\x01\x30\"M\n\x14TGroupDecommitStatus\"5\n\x01\x45\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\x08\n\x04\x44ONE\x10\x03\"\xe0\x05\n\nTGroupInfo\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x03 \x01(\r\x12\x38\n\x05Rings\x18\x04 \x03(\x0b\x32).NKikimrBlobStorage.TGroupInfo.TFailRealm\x12\x37\n\x0c\x45ntityStatus\x18\x05 \x01(\x0e\x32!.NKikimrBlobStorage.EEntityStatus\x12\x19\n\x0e\x45ncryptionMode\x18\x06 \x01(\r:\x01\x30\x12\x19\n\x0eLifeCyclePhase\x18\x07 \x01(\r:\x01\x30\x12\x13\n\tMainKeyId\x18\x08 \x01(\x0c:\x00\x12\x1b\n\x11\x45ncryptedGroupKey\x18\t \x01(\x0c:\x00\x12\x18\n\rGroupKeyNonce\x18\n \x01(\x04:\x01\x30\x12\x19\n\x0eMainKeyVersion\x18\x0b \x01(\x04:\x01\x30\x12\x34\n\rAcceptedScope\x18\x0c \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x17\n\x0fStoragePoolName\x18\r \x01(\t\x12\x32\n\nDeviceType\x18\x0e \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x13\n\x0b\x42lobDepotId\x18\x0f \x01(\x04\x12\x42\n\x0e\x44\x65\x63ommitStatus\x18\x10 \x01(\x0e\x32*.NKikimrBlobStorage.TGroupDecommitStatus.E\x1a\xa3\x01\n\nTFailRealm\x12J\n\x0b\x46\x61ilDomains\x18\x01 \x03(\x0b\x32\x35.NKikimrBlobStorage.TGroupInfo.TFailRealm.TFailDomain\x1aI\n\x0bTFailDomain\x12:\n\x0eVDiskLocations\x18\x01 \x03(\x0b\x32\".NKikimrBlobStorage.TVDiskLocation\"\xb0\x02\n\x0eTEvVPatchStart\x12\x31\n\x0eOriginalBlobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x30\n\rPatchedBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x04 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xc2\x03\n\x13TEvVPatchFoundParts\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12\x31\n\x0eOriginalBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x30\n\rPatchedBlobId\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x15\n\rOriginalParts\x18\x06 \x03(\r\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\",\n\nTDiffBlock\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x0e\n\x06\x42uffer\x18\x02 \x01(\x0c\"Q\n\x10TXorDiffReceiver\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06PartId\x18\x02 \x01(\r\"\xce\x03\n\rTEvVPatchDiff\x12\x35\n\x12OriginalPartBlobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x34\n\x11PatchedPartBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12-\n\x05\x44iffs\x18\x04 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDiffBlock\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12:\n\x0cXorReceivers\x18\x06 \x03(\x0b\x32$.NKikimrBlobStorage.TXorDiffReceiver\x12\x18\n\x10\x45xpectedXorDiffs\x18\x07 \x01(\r\x12\x10\n\x08\x46orceEnd\x18\x08 \x01(\x08\x12\x18\n\x10NotifyIfNotReady\x18\t \x01(\x08\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xfd\x02\n\x10TEvVPatchXorDiff\x12\x35\n\x12OriginalPartBlobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x34\n\x11PatchedPartBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12-\n\x05\x44iffs\x18\x04 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDiffBlock\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x12\n\nFromPartId\x18\x06 \x01(\r\x12\x18\n\x10NotifyIfNotReady\x18\x07 \x01(\x08\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xa6\x01\n\x16TEvVPatchXorDiffResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xea\x03\n\x0fTEvVPatchResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12\x35\n\x12OriginalPartBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x34\n\x11PatchedPartBlobId\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x13\n\x0bStatusFlags\x18\x06 \x01(\r\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12$\n\x19\x41pproximateFreeSpaceShare\x18\x19 \x01(\x02:\x01\x30\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xa5\x03\n\x0eTEvVMovedPatch\x12\x31\n\x0eOriginalBlobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x30\n\rPatchedBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0fOriginalGroupId\x18\x03 \x01(\r\x12\x16\n\x0ePatchedGroupId\x18\x04 \x01(\r\x12-\n\x05\x44iffs\x18\x05 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDiffBlock\x12-\n\x07VDiskID\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x13\n\x0bIgnoreBlock\x18\x07 \x01(\x08\x12\x18\n\x10NotifyIfNotReady\x18\x08 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\t \x01(\x04\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xe7\x03\n\x14TEvVMovedPatchResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12\x31\n\x0eOriginalBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x30\n\rPatchedBlobId\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x13\n\x0bStatusFlags\x18\x06 \x01(\r\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12$\n\x19\x41pproximateFreeSpaceShare\x18\x19 \x01(\x02:\x01\x30\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xa7\x03\n\x10TEvVInplacePatch\x12\x31\n\x0eOriginalBlobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x30\n\rPatchedBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0fOriginalGroupId\x18\x03 \x01(\r\x12\x16\n\x0ePatchedGroupId\x18\x04 \x01(\r\x12-\n\x05\x44iffs\x18\x05 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDiffBlock\x12-\n\x07VDiskID\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x13\n\x0bIgnoreBlock\x18\x07 \x01(\x08\x12\x18\n\x10NotifyIfNotReady\x18\x08 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\t \x01(\x04\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xe9\x03\n\x16TEvVInplacePatchResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12\x31\n\x0eOriginalBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x30\n\rPatchedBlobId\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x13\n\x0bStatusFlags\x18\x06 \x01(\r\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12$\n\x19\x41pproximateFreeSpaceShare\x18\x19 \x01(\x02:\x01\x30\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xe6\x03\n\x07TEvVPut\x12)\n\x06\x42lobID\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x0e\n\x06\x42uffer\x18\x02 \x01(\x0c\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x14\n\x0c\x46ullDataSize\x18\x04 \x01(\x04\x12\x13\n\x0bIgnoreBlock\x18\x05 \x01(\x08\x12\x18\n\x10NotifyIfNotReady\x18\x06 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\x07 \x01(\x04\x12\x38\n\x0bHandleClass\x18\t \x01(\x0e\x32#.NKikimrBlobStorage.EPutHandleClass\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12\x46\n\x10\x45xtraBlockChecks\x18\x0b \x03(\x0b\x32,.NKikimrBlobStorage.TEvVPut.TExtraBlockCheck\x1a\x38\n\x10TExtraBlockCheck\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\"\xc4\x03\n\rTEvVPutResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x1c\n\x14WrittenBeyondBarrier\x18\x06 \x01(\x08\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x04 \x01(\x04\x12\x13\n\x0bStatusFlags\x18\x05 \x01(\r\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12$\n\x19\x41pproximateFreeSpaceShare\x18\x19 \x01(\x02:\x01\x30\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xe2\x01\n\x0eTVMultiPutItem\x12)\n\x06\x42lobID\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x0e\n\x06\x42uffer\x18\x02 \x01(\x0c\x12\x14\n\x0c\x46ullDataSize\x18\x03 \x01(\x04\x12\x0e\n\x06\x43ookie\x18\x04 \x01(\x04\x12\x46\n\x10\x45xtraBlockChecks\x18\x05 \x03(\x0b\x32,.NKikimrBlobStorage.TEvVPut.TExtraBlockCheck\x12\'\n\x07TraceId\x18\x06 \x01(\x0b\x32\x16.NActorsProto.TTraceId\"\xd2\x02\n\x0cTEvVMultiPut\x12\x31\n\x05Items\x18\x01 \x03(\x0b\x32\".NKikimrBlobStorage.TVMultiPutItem\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x1a\n\x0bIgnoreBlock\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x18\n\x10NotifyIfNotReady\x18\x04 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x38\n\x0bHandleClass\x18\x06 \x01(\x0e\x32#.NKikimrBlobStorage.EPutHandleClass\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\"\xc9\x01\n\x14TVMultiPutResultItem\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x1c\n\x14WrittenBeyondBarrier\x18\x05 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x04\x12\x16\n\x0bStatusFlags\x18\x04 \x01(\r:\x01\x30\"\xbc\x03\n\x12TEvVMultiPutResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x14\n\x0b\x45rrorReason\x18\xc8\x01 \x01(\t\x12\x37\n\x05Items\x18\x02 \x03(\x0b\x32(.NKikimrBlobStorage.TVMultiPutResultItem\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x04 \x01(\x04\x12\x16\n\x0bStatusFlags\x18\x05 \x01(\r:\x01\x30\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12$\n\x19\x41pproximateFreeSpaceShare\x18\x19 \x01(\x02:\x01\x30\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\x81\x01\n\x0bTRangeQuery\x12\'\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12%\n\x02To\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x0e\n\x06\x43ookie\x18\x06 \x01(\x04\x12\x12\n\nMaxResults\x18\x07 \x01(\r\"c\n\rTExtremeQuery\x12%\n\x02Id\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\r\n\x05Shift\x18\x02 \x01(\x04\x12\x0c\n\x04Size\x18\x03 \x01(\x04\x12\x0e\n\x06\x43ookie\x18\x04 \x01(\x04\"\xf2\x05\n\x07TEvVGet\x12\x33\n\nRangeQuery\x18\x05 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TRangeQuery\x12\x39\n\x0e\x45xtremeQueries\x18\x06 \x03(\x0b\x32!.NKikimrBlobStorage.TExtremeQuery\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x03 \x01(\x08\x12\x15\n\rShowInternals\x18\x04 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\t \x01(\x04\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x18\n\tIndexOnly\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\x38\n\x0bHandleClass\x18\r \x01(\x0e\x32#.NKikimrBlobStorage.EGetHandleClass\x12#\n\x14SuppressBarrierCheck\x18\x14 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x08TabletId\x18\x15 \x01(\x04:\x01\x30\x12\'\n\x18\x41\x63quireBlockedGeneration\x18\x16 \x01(\x08:\x05\x66\x61lse\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12!\n\x16\x46orceBlockedGeneration\x18\x18 \x01(\r:\x01\x30\x12\x41\n\x10ReaderTabletData\x18\x19 \x01(\x0b\x32\'.NKikimrBlobStorage.TEvVGet.TTabletData\x12\x45\n\x14\x46orceBlockTabletData\x18\x1a \x01(\x0b\x32\'.NKikimrBlobStorage.TEvVGet.TTabletData\x12\x12\n\nSnapshotId\x18\x1e \x01(\x0c\x1a-\n\x0bTTabletData\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\"\xf9\x01\n\x0cTQueryResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\r\n\x05Shift\x18\x03 \x01(\x04\x12\x0c\n\x04Size\x18\x04 \x01(\x04\x12\x0e\n\x06\x42uffer\x18\x05 \x01(\x0c\x12\x0e\n\x06\x43ookie\x18\x06 \x01(\x04\x12\x14\n\x0c\x46ullDataSize\x18\x07 \x01(\x04\x12\x0f\n\x07Ingress\x18\x08 \x01(\x04\x12\r\n\x05Parts\x18\t \x03(\r\x12\x0c\n\x04Keep\x18\n \x01(\x08\x12\x11\n\tDoNotKeep\x18\x0b \x01(\x08\"\x9a\x03\n\rTEvVGetResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x30\n\x06Result\x18\x02 \x03(\x0b\x32 .NKikimrBlobStorage.TQueryResult\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x1c\n\x11\x42lockedGeneration\x18\x0b \x01(\r:\x01\x30\x12\x33\n\nTimestamps\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TTimestamps\x12\x1e\n\x0fIsRangeOverflow\x18\x18 \x01(\x08:\x05\x66\x61lse\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xbb\x01\n\tTEvVBlock\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x12\n\nIssuerGuid\x18\x05 \x01(\x04\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x04 \x01(\x08\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\"\x8d\x02\n\x0fTEvVBlockResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\x96\x01\n\x0cTEvVGetBlock\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x03 \x01(\x08\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\"\xf7\x01\n\x12TEvVGetBlockResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\x9f\x02\n\x0eTEvVAssimilate\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\x12\x16\n\x0eSkipBlocksUpTo\x18\n \x01(\x06\x12H\n\x10SkipBarriersUpTo\x18\x0b \x01(\x0b\x32..NKikimrBlobStorage.TEvVAssimilate.TBarrierKey\x12\x30\n\rSkipBlobsUpTo\x18\x0c \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x1a\x30\n\x0bTBarrierKey\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\"\xe0\x06\n\x14TEvVAssimilateResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12?\n\x06\x42locks\x18\n \x03(\x0b\x32/.NKikimrBlobStorage.TEvVAssimilateResult.TBlock\x12\x43\n\x08\x42\x61rriers\x18\x0b \x03(\x0b\x32\x31.NKikimrBlobStorage.TEvVAssimilateResult.TBarrier\x12=\n\x05\x42lobs\x18\x0c \x03(\x0b\x32..NKikimrBlobStorage.TEvVAssimilateResult.TBlob\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\x1a\x35\n\x06TBlock\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x19\n\x11\x42lockedGeneration\x18\x02 \x01(\r\x1a\xaf\x02\n\x08TBarrier\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x46\n\x04Soft\x18\x03 \x01(\x0b\x32\x38.NKikimrBlobStorage.TEvVAssimilateResult.TBarrier.TValue\x12\x46\n\x04Hard\x18\x04 \x01(\x0b\x32\x38.NKikimrBlobStorage.TEvVAssimilateResult.TBarrier.TValue\x1ap\n\x06TValue\x12\x18\n\x10RecordGeneration\x18\x01 \x01(\r\x12\x1c\n\x14PerGenerationCounter\x18\x02 \x01(\r\x12\x19\n\x11\x43ollectGeneration\x18\x03 \x01(\r\x12\x13\n\x0b\x43ollectStep\x18\x04 \x01(\r\x1au\n\x05TBlob\x12\r\n\x05RawX1\x18\x01 \x01(\x06\x12\r\n\x05RawX2\x18\x02 \x01(\x06\x12\r\n\x05RawX3\x18\x03 \x01(\x06\x12\x0e\n\x06\x44iffX1\x18\x04 \x01(\x04\x12\x0e\n\x06\x44iffX2\x18\x05 \x01(\x04\x12\x0e\n\x06\x44iffX3\x18\x06 \x01(\x04\x12\x0f\n\x07Ingress\x18\x07 \x01(\x04\"\x86\x01\n\x10TEvVTakeSnapshot\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\x12\x12\n\nSnapshotId\x18\x03 \x01(\x0c\x12\x15\n\rTimeToLiveSec\x18\x04 \x01(\r\"\x88\x01\n\x16TEvVTakeSnapshotResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"r\n\x13TEvVReleaseSnapshot\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\x12\x12\n\nSnapshotId\x18\x03 \x01(\x0c\"\x8b\x01\n\x19TEvVReleaseSnapshotResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"\x81\x03\n\x12TEvVCollectGarbage\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x18\n\x10RecordGeneration\x18\x02 \x01(\r\x12\x1c\n\x14PerGenerationCounter\x18\x0b \x01(\r\x12\x0f\n\x07\x43hannel\x18\x03 \x01(\r\x12\x19\n\x11\x43ollectGeneration\x18\x04 \x01(\r\x12\x13\n\x0b\x43ollectStep\x18\x05 \x01(\r\x12\x13\n\x04Hard\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\'\n\x04Keep\x18\x06 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12,\n\tDoNotKeep\x18\x07 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12-\n\x07VDiskID\x18\x08 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\t \x01(\x08\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\"\xad\x02\n\x18TEvVCollectGarbageResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x18\n\x10RecordGeneration\x18\x03 \x01(\r\x12\x0f\n\x07\x43hannel\x18\x04 \x01(\r\x12-\n\x07VDiskID\x18\x05 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"v\n\x0bTBarrierKey\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x18\n\x10RecordGeneration\x18\x03 \x01(\r\x12\x1c\n\x14PerGenerationCounter\x18\x04 \x01(\r\x12\x0c\n\x04Hard\x18\x05 \x01(\x08\"G\n\x0bTBarrierVal\x12\x12\n\nCollectGen\x18\x01 \x01(\r\x12\x13\n\x0b\x43ollectStep\x18\x02 \x01(\r\x12\x0f\n\x07Ingress\x18\x05 \x01(\r\"\x8d\x02\n\x0eTEvVGetBarrier\x12-\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBarrierKey\x12+\n\x02To\x18\x02 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBarrierKey\x12\x12\n\nMaxResults\x18\x03 \x01(\r\x12-\n\x07VDiskID\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x05 \x01(\x08\x12\x15\n\rShowInternals\x18\x06 \x01(\x08\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\"\xb3\x02\n\x14TEvVGetBarrierResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12-\n\x04Keys\x18\x02 \x03(\x0b\x32\x1f.NKikimrBlobStorage.TBarrierKey\x12/\n\x06Values\x18\x04 \x03(\x0b\x32\x1f.NKikimrBlobStorage.TBarrierVal\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12+\n\x06MsgQoS\x18\n \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xbc\x01\n\x12TEvVCheckReadiness\x12\x18\n\x10NotifyIfNotReady\x18\x01 \x01(\x08\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x33\n\x0bRecentGroup\x18\x04 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\x12(\n\x03QoS\x18\x05 \x01(\x0b\x32\x1b.NKikimrBlobStorage.TMsgQoS\"\x91\x02\n\x18TEvVCheckReadinessResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x35\n\rExpectedMsgId\x18\x03 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TMessageId\x12<\n\x0c\x43ostSettings\x18\x04 \x01(\x0b\x32&.NKikimrBlobStorage.TVDiskCostSettings\x12\x1f\n\x17\x45xtraBlockChecksSupport\x18\x05 \x01(\x08\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\x11\n\x0fTEvVReadyNotify\"-\n\nTSyncState\x12\x0c\n\x04Guid\x18\x01 \x01(\x04\x12\x11\n\tSyncedLsn\x18\x02 \x01(\x04\"\x86\x01\n\rTSyncGuidInfo\x12\x0c\n\x04Guid\x18\x01 \x01(\x04\x12\x37\n\x05State\x18\x02 \x01(\x0e\x32(.NKikimrBlobStorage.TSyncGuidInfo.EState\".\n\x06\x45State\x12\t\n\x05\x45mpty\x10\x01\x12\x0e\n\nInProgress\x10\x02\x12\t\n\x05\x46inal\x10\x03\"\xa4\x01\n\x0eTLocalGuidInfo\x12\x0c\n\x04Guid\x18\x01 \x01(\x04\x12\x38\n\x05State\x18\x02 \x01(\x0e\x32).NKikimrBlobStorage.TLocalGuidInfo.EState\x12\x12\n\nDbBirthLsn\x18\x03 \x01(\x04\"6\n\x06\x45State\x12\t\n\x05\x45mpty\x10\x01\x12\x0c\n\x08Selected\x10\x02\x12\x08\n\x04Lost\x10\x03\x12\t\n\x05\x46inal\x10\x04\"\xc3\x01\n\x0cTEvVSyncGuid\x12\x33\n\rSourceVDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x33\n\rTargetVDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x04 \x01(\x08\x12/\n\x04Info\x18\x07 \x01(\x0b\x32!.NKikimrBlobStorage.TSyncGuidInfo\"\xa4\x01\n\x12TEvVSyncGuidResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x33\n\x08ReadInfo\x18\x07 \x01(\x0b\x32!.NKikimrBlobStorage.TSyncGuidInfo\"\xc1\x01\n\x08TEvVSync\x12\x31\n\tSyncState\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x33\n\rSourceVDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x33\n\rTargetVDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x04 \x01(\x08\"\xe0\x02\n\x0eTEvVSyncResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x34\n\x0cOldSyncState\x18\x02 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x34\n\x0cNewSyncState\x18\x03 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x10\n\x08\x46inished\x18\x04 \x01(\x08\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12-\n\x07VDiskID\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x36\n\x04Stat\x18\x07 \x01(\x0b\x32(.NKikimrBlobStorage.TEvVSyncResult.TStat\x12\x13\n\x0bStatusFlags\x18\x08 \x01(\r\x1a\x1a\n\x05TStat\x12\x11\n\tDiskReads\x18\x01 \x01(\r\"\x88\x03\n\x0cTEvVSyncFull\x12\x31\n\tSyncState\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x33\n\rSourceVDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x33\n\rTargetVDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x04 \x01(\x08\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x31\n\x05Stage\x18\x0b \x01(\x0e\x32\".NKikimrBlobStorage.ESyncFullStage\x12/\n\x0cLogoBlobFrom\x18\x0c \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0f\x42lockTabletFrom\x18\r \x01(\x04\x12\x34\n\x0b\x42\x61rrierFrom\x18\x0e \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBarrierKey\"\x85\x03\n\x12TEvVSyncFullResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x31\n\tSyncState\x18\x02 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x10\n\x08\x46inished\x18\x04 \x01(\x08\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12-\n\x07VDiskID\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06\x43ookie\x18\x07 \x01(\x04\x12\x31\n\x05Stage\x18\x0b \x01(\x0e\x32\".NKikimrBlobStorage.ESyncFullStage\x12/\n\x0cLogoBlobFrom\x18\x0c \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0f\x42lockTabletFrom\x18\r \x01(\x04\x12\x34\n\x0b\x42\x61rrierFrom\x18\x0e \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBarrierKey\"Q\n\x13THandoffDelLogoBlob\x12)\n\x06\x42lobID\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x0f\n\x07Ingress\x18\x02 \x01(\x04\"\"\n\rTHullDbStatus\x12\x11\n\tCompacted\x18\x01 \x01(\x08\"\xf0\x01\n\rTSyncerStatus\x12\x37\n\x05Phase\x18\x02 \x01(\x0e\x32(.NKikimrBlobStorage.TSyncerStatus.EPhase\x12\x31\n\tSyncState\x18\x01 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\"s\n\x06\x45Phase\x12\r\n\tPhaseNone\x10\x01\x12\x11\n\rPhaseSyncGuid\x10\x02\x12\x18\n\x14PhaseRecoverLostData\x10\x03\x12\x15\n\x11PhaseStandardMode\x10\x04\x12\x16\n\x12PhaseInconsistency\x10\x05\"\xa4\x01\n\x0eTSyncLogStatus\x12\x13\n\x0bLogStartLsn\x18\x01 \x01(\x04\x12\x13\n\x0bMemLogEmpty\x18\x02 \x01(\x08\x12\x14\n\x0c\x44iskLogEmpty\x18\x03 \x01(\x08\x12\x13\n\x0b\x46irstMemLsn\x18\x04 \x01(\x04\x12\x12\n\nLastMemLsn\x18\x05 \x01(\x04\x12\x14\n\x0c\x46irstDiskLsn\x18\x06 \x01(\x04\x12\x13\n\x0bLastDiskLsn\x18\x07 \x01(\x04\"\x83\x02\n\x12TLocalRecoveryInfo\x12\x10\n\x08StartLsn\x18\x01 \x01(\x04\x12\x1a\n\x12SuccessfulRecovery\x18\x05 \x01(\x08\x12\x18\n\x10\x45mptyLogoBlobsDb\x18\x0b \x01(\x08\x12\x15\n\rEmptyBlocksDb\x18\x0c \x01(\x08\x12\x17\n\x0f\x45mptyBarriersDb\x18\r \x01(\x08\x12\x14\n\x0c\x45mptySyncLog\x18\x0e \x01(\x08\x12\x13\n\x0b\x45mptySyncer\x18\x0f \x01(\x08\x12\x11\n\tEmptyHuge\x18\x10 \x01(\x08\x12\x1b\n\x13RecoveryLogFirstLsn\x18) \x01(\x04\x12\x1a\n\x12RecoveryLogLastLsn\x18* \x01(\x04\"U\n\nTEvVStatus\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\"\xf8\x04\n\x10TEvVStatusResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x34\n\tLogoBlobs\x18\x02 \x01(\x0b\x32!.NKikimrBlobStorage.THullDbStatus\x12\x31\n\x06\x42locks\x18\x03 \x01(\x0b\x32!.NKikimrBlobStorage.THullDbStatus\x12\x33\n\x08\x42\x61rriers\x18\x04 \x01(\x0b\x32!.NKikimrBlobStorage.THullDbStatus\x12\x37\n\x0cSyncerStatus\x18\x05 \x01(\x0b\x32!.NKikimrBlobStorage.TSyncerStatus\x12\x39\n\rSyncLogStatus\x18\x06 \x01(\x0b\x32\".NKikimrBlobStorage.TSyncLogStatus\x12\x41\n\x11LocalRecoveryInfo\x18\x07 \x01(\x0b\x32&.NKikimrBlobStorage.TLocalRecoveryInfo\x12-\n\x07VDiskID\x18\x08 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x13\n\x0bStatusFlags\x18\t \x01(\r\x12\x13\n\x0bJoinedGroup\x18\n \x01(\x08\x12\x19\n\nReplicated\x18\x0b \x01(\x08:\x05\x66\x61lse\x12!\n\x19\x41pproximateFreeSpaceShare\x18\x0c \x01(\x02\x12\x17\n\x0fIncarnationGuid\x18\x1e \x01(\x06\x12\x33\n\x0bRecentGroup\x18\x64 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\"\xdc\x02\n\nTEvVDbStat\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\x12-\n\x04Type\x18\x03 \x01(\x0e\x32\x1f.NKikimrBlobStorage.EDbStatType\x12\x31\n\x06\x41\x63tion\x18\x04 \x01(\x0e\x32!.NKikimrBlobStorage.EDbStatAction\x12\x13\n\x0bPrettyPrint\x18\x05 \x01(\x08\x12\x10\n\x08TabletId\x18\x06 \x01(\x06\x12\x44\n\nConstraint\x18\x07 \x01(\x0b\x32\x30.NKikimrBlobStorage.TEvVDbStat.TDumpDbConstraint\x1a\x36\n\x11TDumpDbConstraint\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\"\xdd\x01\n\x10TEvVDbStatResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12-\n\x04Type\x18\x03 \x01(\x0e\x32\x1f.NKikimrBlobStorage.EDbStatType\x12\x31\n\x06\x41\x63tion\x18\x04 \x01(\x0e\x32!.NKikimrBlobStorage.EDbStatAction\x12\x0c\n\x04\x44\x61ta\x18\n \x01(\t\"\xad\x02\n\x0bTEvVCompact\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\x12@\n\x06OpType\x18\x03 \x01(\x0e\x32\'.NKikimrBlobStorage.TEvVCompact.EOpType:\x07UNKNOWN\x12\x1e\n\x10\x43ompactLogoBlobs\x18\x04 \x01(\x08:\x04true\x12\x1b\n\rCompactBlocks\x18\x05 \x01(\x08:\x04true\x12\x1d\n\x0f\x43ompactBarriers\x18\x06 \x01(\x08:\x04true\"7\n\x07\x45OpType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41SYNC\x10\x01\x12\x08\n\x04SYNC\x10\x02\x12\n\n\x06STATUS\x10\x03\"n\n\x11TEvVCompactResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"c\n\nTEvVDefrag\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\x12\x0c\n\x04\x46ull\x18\x03 \x01(\x08\"\xeb\x01\n\x10TEvVDefragResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x1e\n\x13\x46oundChunksToDefrag\x18\x0b \x01(\x04:\x01\x30\x12\x18\n\rRewrittenRecs\x18\x0c \x01(\x04:\x01\x30\x12\x19\n\x0eRewrittenBytes\x18\r \x01(\x04:\x01\x30\x12\x12\n\x03\x45of\x18\x0e \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0b\x46reedChunks\x18\x0f \x03(\r\"Z\n\x0fTEvVBaldSyncLog\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10NotifyIfNotReady\x18\x02 \x01(\x08\"r\n\x15TEvVBaldSyncLogResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12-\n\x07VDiskID\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"Y\n\x0eTVDiskLocation\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x0f\n\x07PDiskID\x18\x02 \x01(\r\x12\x13\n\x0bVDiskSlotID\x18\x03 \x01(\r\x12\x11\n\tPDiskGuid\x18\x04 \x01(\x04\"\xec\x0e\n\x15TNodeWardenServiceSet\x12@\n\x06PDisks\x18\x01 \x03(\x0b\x32\x30.NKikimrBlobStorage.TNodeWardenServiceSet.TPDisk\x12@\n\x06VDisks\x18\x02 \x03(\x0b\x32\x30.NKikimrBlobStorage.TNodeWardenServiceSet.TVDisk\x12.\n\x06Groups\x18\x03 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\x12\x1b\n\x13\x41vailabilityDomains\x18\x04 \x03(\x04\x12U\n\x10ReplBrokerConfig\x18\x05 \x01(\x0b\x32;.NKikimrBlobStorage.TNodeWardenServiceSet.TReplBrokerConfig\x12\x17\n\x0f\x45nableProxyMock\x18\x07 \x01(\x08\x1a\x9a\x03\n\x06TPDisk\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x0f\n\x07PDiskID\x18\x02 \x01(\r\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\x11\n\tPDiskGuid\x18\x05 \x01(\x04\x12\x15\n\rPDiskCategory\x18\x06 \x01(\x04\x12\x35\n\x0bPDiskConfig\x18\x07 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\x12\x37\n\x0c\x45ntityStatus\x18\t \x01(\x0e\x32!.NKikimrBlobStorage.EEntityStatus\x12&\n\x1bInMemoryForTestsBufferBytes\x18\n \x01(\x04:\x01\x30\x12\x16\n\x0e\x45xpectedSerial\x18\x0b \x01(\t\x12\x45\n\x0fManagementStage\x18\x0c \x01(\x0e\x32,.NKikimrBlobStorage.TSerialManagementStage.E\x12@\n\x10SpaceColorBorder\x18\r \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x1a\xc1\x05\n\x06TVDisk\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x39\n\rVDiskLocation\x18\x02 \x01(\x0b\x32\".NKikimrBlobStorage.TVDiskLocation\x12<\n\tVDiskKind\x18\x03 \x01(\x0e\x32).NKikimrBlobStorage.TVDiskKind.EVDiskKind\x12\x18\n\tDoDestroy\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x15\n\x06\x44oWipe\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x37\n\x0c\x45ntityStatus\x18\x06 \x01(\x0e\x32!.NKikimrBlobStorage.EEntityStatus\x12\x17\n\x0fStoragePoolName\x18\x08 \x01(\t\x12N\n\tDonorMode\x18\t \x01(\x0b\x32;.NKikimrBlobStorage.TNodeWardenServiceSet.TVDisk.TDonorMode\x12G\n\x06\x44onors\x18\n \x03(\x0b\x32\x37.NKikimrBlobStorage.TNodeWardenServiceSet.TVDisk.TDonor\x1ar\n\x06TDonor\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x39\n\rVDiskLocation\x18\x02 \x01(\x0b\x32\".NKikimrBlobStorage.TVDiskLocation\x1a\x7f\n\nTDonorMode\x12\x15\n\rNumFailRealms\x18\x01 \x01(\r\x12\"\n\x1aNumFailDomainsPerFailRealm\x18\x02 \x01(\r\x12\x1e\n\x16NumVDisksPerFailDomain\x18\x03 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x04 \x01(\r\x1a\xb0\x03\n\x11TReplBrokerConfig\x12\'\n\x12RateBytesPerSecond\x18\x01 \x01(\x04:\x0b\x31\x30\x30\x30\x30\x30\x30\x30\x30\x30\x30\x12!\n\x14\x43\x61pacityMilliseconds\x18\x02 \x01(\x04:\x03\x31\x30\x30\x12\'\n\x14MaxInFlightReadBytes\x18\x03 \x01(\x04:\t335544320\x12\x63\n\x0eMediaTypeQuota\x18\x04 \x03(\x0b\x32K.NKikimrBlobStorage.TNodeWardenServiceSet.TReplBrokerConfig.TMediaTypeQuota\x12\"\n\x1aTotalRequestBytesPerSecond\x18\x05 \x01(\x04\x12#\n\x1bTotalResponseBytesPerSecond\x18\x06 \x01(\x04\x1ax\n\x0fTMediaTypeQuota\x12,\n\x04Type\x18\x01 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x1a\n\x12ReadBytesPerSecond\x18\x02 \x01(\x04\x12\x1b\n\x13WriteBytesPerSecond\x18\x03 \x01(\x04\"z\n\x10TNodeWardenCache\x12\x13\n\x0b\x41vailDomain\x18\x01 \x01(\x04\x12\x12\n\nInstanceId\x18\x02 \x01(\t\x12=\n\nServiceSet\x18\x03 \x01(\x0b\x32).NKikimrBlobStorage.TNodeWardenServiceSet\"E\n\x12TMockDevicesConfig\x12/\n\x07\x44\x65vices\x18\x01 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDriveData\"\xb8\x01\n\nTDriveData\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x14\n\x0cSerialNumber\x18\x02 \x01(\t\x12\x18\n\x10\x46irmwareRevision\x18\x03 \x01(\t\x12\x13\n\x0bModelNumber\x18\x04 \x01(\t\x12\x0c\n\x04Size\x18\x06 \x01(\x04\x12\x15\n\x06IsMock\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x32\n\nDeviceType\x18\x05 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\"\xc6\x01\n\x19TEvControllerRegisterNode\x12\x0e\n\x06NodeID\x18\x02 \x01(\r\x12\x0e\n\x06Groups\x18\x04 \x03(\r\x12\x18\n\x10GroupGenerations\x18\x05 \x03(\r\x12\x35\n\x0bVDiskStatus\x18\x06 \x03(\x0b\x32 .NKikimrBlobStorage.TVDiskStatus\x12\x32\n\nDrivesData\x18\x07 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDriveDataJ\x04\x08\x01\x10\x02\"c\n\x1dTEvControllerUpdateNodeDrives\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x32\n\nDrivesData\x18\x02 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDriveData\"\xf9\x02\n!TEvControllerNodeServiceSetUpdate\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06NodeID\x18\x02 \x01(\r\x12=\n\nServiceSet\x18\x03 \x01(\x0b\x32).NKikimrBlobStorage.TNodeWardenServiceSet\x12[\n\rGroupMetadata\x18\x04 \x03(\x0b\x32\x44.NKikimrBlobStorage.TEvControllerNodeServiceSetUpdate.TGroupMetadata\x12\x12\n\nInstanceId\x18\x05 \x01(\t\x12\x15\n\rComprehensive\x18\x06 \x01(\x08\x12\x13\n\x0b\x41vailDomain\x18\x07 \x01(\x04\x1a<\n\x0eTGroupMetadata\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x19\n\x11\x43urrentGeneration\x18\x02 \x01(\r\"X\n!TEvControllerGroupReconfigureWipe\x12-\n\x07VSlotId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotIdJ\x04\x08\x01\x10\x02\"j\n\'TEvControllerGroupReconfigureWipeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\"]\n\x1aTEvControllerConfigRequest\x12\x33\n\x07Request\x18\x02 \x01(\x0b\x32\".NKikimrBlobStorage.TConfigRequestJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\"Z\n\x1bTEvControllerConfigResponse\x12\x35\n\x08Response\x18\x01 \x01(\x0b\x32#.NKikimrBlobStorage.TConfigResponseJ\x04\x08\x02\x10\x03\"9\n\x15TEvControllerGetGroup\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x10\n\x08GroupIDs\x18\x02 \x03(\r\"\xc7\x01\n\x1cTEvControllerProposeGroupKey\x12\x11\n\x06NodeId\x18\x01 \x01(\r:\x01\x30\x12\x12\n\x07GroupId\x18\x02 \x01(\r:\x01\x30\x12\x19\n\x0eLifeCyclePhase\x18\x03 \x01(\r:\x01\x30\x12\x13\n\tMainKeyId\x18\x04 \x01(\x0c:\x00\x12\x1b\n\x11\x45ncryptedGroupKey\x18\x05 \x01(\x0c:\x00\x12\x19\n\x0eMainKeyVersion\x18\x06 \x01(\x04:\x01\x30\x12\x18\n\rGroupKeyNonce\x18\x07 \x01(\x04:\x01\x30\"l\n\x16TStorageOwnerGroupInfo\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x16\n\x0eReadThroughput\x18\x02 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\x03 \x01(\x04\x12\x10\n\x08\x44\x61taSize\x18\x04 \x01(\x04\"u\n\x11TStorageOwnerInfo\x12\x0f\n\x07OwnerID\x18\x01 \x01(\x04\x12=\n\tGroupInfo\x18\x02 \x03(\x0b\x32*.NKikimrBlobStorage.TStorageOwnerGroupInfo\x12\x10\n\x08\x44\x61taSize\x18\x03 \x01(\x04\"\x89\x05\n\x19TEvControllerSelectGroups\x12W\n\x0fGroupParameters\x18\x03 \x03(\x0b\x32>.NKikimrBlobStorage.TEvControllerSelectGroups.TGroupParameters\x12?\n\x10StorageOwnerInfo\x18\x04 \x01(\x0b\x32%.NKikimrBlobStorage.TStorageOwnerInfo\x12\x10\n\x08ObjectId\x18\x05 \x01(\x04\x12\x1f\n\x17ReturnAllMatchingGroups\x18\x06 \x01(\x08\x12)\n!BlockUntilAllResourcesAreComplete\x18\x07 \x01(\x08\x12\x1b\n\x13OnlySeenOperational\x18\x08 \x01(\x08\x1a\x33\n\x15TStoragePoolSpecifier\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Kind\x18\x02 \x01(\t\x1a\x95\x02\n\x10TGroupParameters\x12\x16\n\x0e\x45rasureSpecies\x18\x01 \x01(\r\x12\x1c\n\x14\x44\x65siredPDiskCategory\x18\x02 \x01(\x04\x12\x1c\n\x14\x44\x65siredVDiskCategory\x18\x03 \x01(\x04\x12\x14\n\x0cRequiredIOPS\x18\x04 \x01(\x02\x12\x1a\n\x12RequiredThroughput\x18\x05 \x01(\x04\x12\x18\n\x10RequiredDataSize\x18\x06 \x01(\x04\x12\x61\n\x14StoragePoolSpecifier\x18\x07 \x01(\x0b\x32\x43.NKikimrBlobStorage.TEvControllerSelectGroups.TStoragePoolSpecifierJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xb4\x01\n\x0cTVDiskStatus\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x0f\n\x07PDiskId\x18\x03 \x01(\r\x12\x0f\n\x07VSlotId\x18\x04 \x01(\r\x12\x11\n\tPDiskGuid\x18\x05 \x01(\x04\x12\x30\n\x06Status\x18\x06 \x01(\x0e\x32 .NKikimrBlobStorage.EVDiskStatus\"\xca\x01\n\x1dTEvControllerUpdateDiskStatus\x12\x38\n\rVDisksMetrics\x18\x01 \x03(\x0b\x32!.NKikimrBlobStorage.TVDiskMetrics\x12\x38\n\rPDisksMetrics\x18\x02 \x03(\x0b\x32!.NKikimrBlobStorage.TPDiskMetrics\x12\x35\n\x0bVDiskStatus\x18\x03 \x03(\x0b\x32 .NKikimrBlobStorage.TVDiskStatus\"\xe5\x02\n\x12TEvGroupStatReport\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12.\n\x0eVDiskServiceId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12N\n\x0cPutTabletLog\x18\n \x01(\x0b\x32\x38.NKikimrBlobStorage.TEvGroupStatReport.TLatencyHistogram\x12M\n\x0bPutUserData\x18\x0b \x01(\x0b\x32\x38.NKikimrBlobStorage.TEvGroupStatReport.TLatencyHistogram\x12I\n\x07GetFast\x18\x0c \x01(\x0b\x32\x38.NKikimrBlobStorage.TEvGroupStatReport.TLatencyHistogram\x1a$\n\x11TLatencyHistogram\x12\x0f\n\x07\x42uckets\x18\x01 \x03(\r\"^\n\x1cTEvControllerUpdateGroupStat\x12>\n\x0ePerGroupReport\x18\x01 \x03(\x0b\x32&.NKikimrBlobStorage.TEvGroupStatReport\"\x81\x07\n\x1fTEvControllerSelectGroupsResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12\x1e\n\x16NewStyleQuerySupported\x18\x04 \x01(\x08\x12^\n\x0eMatchingGroups\x18\x05 \x03(\x0b\x32\x46.NKikimrBlobStorage.TEvControllerSelectGroupsResult.TMatchingGroupList\x1a\xb5\x04\n\x10TGroupParameters\x12\x16\n\x0e\x45rasureSpecies\x18\x01 \x01(\r\x12\x0f\n\x07GroupID\x18\x02 \x01(\r\x12\x17\n\x0fStoragePoolName\x18\x03 \x01(\t\x12\x15\n\rPhysicalGroup\x18\x0c \x01(\x08\x12\x13\n\x0b\x44\x65\x63ommitted\x18\r \x01(\x08\x12i\n\x10\x41ssuredResources\x18\x07 \x01(\x0b\x32O.NKikimrBlobStorage.TEvControllerSelectGroupsResult.TGroupParameters.TResources\x12i\n\x10\x43urrentResources\x18\x08 \x01(\x0b\x32O.NKikimrBlobStorage.TEvControllerSelectGroupsResult.TGroupParameters.TResources\x12\x15\n\rAvailableSize\x18\t \x01(\x04\x12\x15\n\rAllocatedSize\x18\n \x01(\x04\x12:\n\nSpaceColor\x18\x0b \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x1am\n\nTResources\x12\r\n\x05Space\x18\x01 \x01(\x04\x12\x0c\n\x04IOPS\x18\x02 \x01(\x01\x12\x16\n\x0eReadThroughput\x18\x03 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\x04 \x01(\x04\x12\x11\n\tOccupancy\x18\x05 \x01(\x01J\x04\x08\x04\x10\x05\x1aj\n\x12TMatchingGroupList\x12T\n\x06Groups\x18\x01 \x03(\x0b\x32\x44.NKikimrBlobStorage.TEvControllerSelectGroupsResult.TGroupParameters\"T\n#TEvControllerScrubQueryStartQuantum\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\"^\n\x1eTEvControllerScrubStartQuantum\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\r\n\x05State\x18\x02 \x01(\x0c\"\x81\x01\n!TEvControllerScrubQuantumFinished\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x0f\n\x05State\x18\x02 \x01(\x0cH\x00\x12\x11\n\x07Success\x18\x03 \x01(\x08H\x00\x42\t\n\x07Outcome\"Z\n)TEvControllerScrubReportQuantumInProgress\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\"-\n\x1aTEvRequestBSControllerInfo\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"\x98\x03\n\x1bTEvResponseBSControllerInfo\x12Q\n\x0b\x42SGroupInfo\x18\x01 \x03(\x0b\x32<.NKikimrBlobStorage.TEvResponseBSControllerInfo.TBSGroupInfo\x1a\x8a\x01\n\nTVDiskInfo\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0e\n\x06NodeId\x18\x03 \x01(\r\x12\x15\n\rPDiskCategory\x18\x04 \x01(\x04\x12\x15\n\rVDiskCategory\x18\x05 \x01(\x04\x1a\x98\x01\n\x0cTBSGroupInfo\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x02 \x01(\r\x12M\n\tVDiskInfo\x18\x03 \x03(\x0b\x32:.NKikimrBlobStorage.TEvResponseBSControllerInfo.TVDiskInfo\x12\x10\n\x08\x44\x61taSize\x18\x06 \x01(\x04\"\x87\x03\n\x17TEvControllerNodeReport\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12N\n\x0cVDiskReports\x18\x02 \x03(\x0b\x32\x38.NKikimrBlobStorage.TEvControllerNodeReport.TVDiskReport\x1a\xb4\x01\n\x0cTVDiskReport\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x07VDiskId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x46\n\x05Phase\x18\x03 \x01(\x0e\x32\x37.NKikimrBlobStorage.TEvControllerNodeReport.EVDiskPhase\"U\n\x0b\x45VDiskPhase\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05WIPED\x10\x02\x12\r\n\tDESTROYED\x10\x03\x12\x13\n\x0fOPERATION_ERROR\x10\x04\"\x04\x08\x01\x10\x01\"\x04\x08\x05\x10\x05\"6\n#TEvControllerGroupDecommittedNotify\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"h\n%TEvControllerGroupDecommittedResponse\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\"\x7f\n\rTGroupMetrics\x12\x0f\n\x07GroupId\x18\x01 \x01(\x06\x12]\n\x0fGroupParameters\x18\x02 \x01(\x0b\x32\x44.NKikimrBlobStorage.TEvControllerSelectGroupsResult.TGroupParameters\"s\n!TEvControllerGroupMetricsExchange\x12\x37\n\x0cGroupMetrics\x18\x01 \x03(\x0b\x32!.NKikimrBlobStorage.TGroupMetrics\x12\x15\n\rGroupsToQuery\x18\x02 \x03(\x07\".\n\x1bTEvNodeWardenQueryGroupInfo\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"`\n\x16TEvNodeWardenGroupInfo\x12-\n\x05Group\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\x12\x17\n\x0fStartedGroupIds\x18\x02 \x03(\r*=\n\x0f\x45PutHandleClass\x12\r\n\tTabletLog\x10\x01\x12\r\n\tAsyncBlob\x10\x02\x12\x0c\n\x08UserData\x10\x03*I\n\x0f\x45GetHandleClass\x12\r\n\tAsyncRead\x10\x01\x12\x0c\n\x08\x46\x61stRead\x10\x02\x12\x0c\n\x08\x44iscover\x10\x03\x12\x0b\n\x07LowRead\x10\x04*\xad\x01\n\rEVDiskQueueId\x12\x0b\n\x07Unknown\x10\x00\x12\x10\n\x0cPutTabletLog\x10\x01\x12\x10\n\x0cPutAsyncBlob\x10\x02\x12\x0f\n\x0bPutUserData\x10\x03\x12\x10\n\x0cGetAsyncRead\x10\x04\x12\x0f\n\x0bGetFastRead\x10\x05\x12\x0f\n\x0bGetDiscover\x10\x06\x12\x0e\n\nGetLowRead\x10\x07\x12\t\n\x05\x42\x65gin\x10\x01\x12\x07\n\x03\x45nd\x10\x08\x1a\x02\x10\x01*\xcd\x01\n\x15\x45VDiskInternalQueueId\x12\x0e\n\nIntUnknown\x10\x00\x12\x0c\n\x08IntBegin\x10\x01\x12\x0f\n\x0bIntGetAsync\x10\x01\x12\x0e\n\nIntGetFast\x10\x02\x12\r\n\tIntPutLog\x10\x03\x12\x18\n\x14IntPutHugeForeground\x10\x04\x12\x18\n\x14IntPutHugeBackground\x10\x05\x12\x12\n\x0eIntGetDiscover\x10\x06\x12\x0e\n\nIntLowRead\x10\x07\x12\n\n\x06IntEnd\x10\x08\x1a\x02\x10\x01*\xe4\x02\n\x0c\x45StatusFlags\x12\x11\n\rStatusIsValid\x10\x01\x12\x18\n\x13StatusDiskSpaceCyan\x10\x80\x01\x12\"\n\x1eStatusDiskSpaceLightYellowMove\x10\x02\x12\x1e\n\x19StatusDiskSpaceYellowStop\x10\x80\x04\x12\x1f\n\x1aStatusDiskSpaceLightOrange\x10\x80\x02\x12\x1d\n\x18StatusDiskSpacePreOrange\x10\x80\x08\x12\x19\n\x15StatusDiskSpaceOrange\x10\x04\x12\x16\n\x12StatusDiskSpaceRed\x10\x08\x12\x18\n\x14StatusDiskSpaceBlack\x10@\x12\x18\n\x13StatusMaskDiskSpace\x10\xce\x0f\x12\x12\n\x0eStatusNewOwner\x10\x10\x12(\n$StatusNotEnoughDiskSpaceForOperation\x10 *B\n\rEEntityStatus\x12\x0b\n\x07INITIAL\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\x0b\n\x07\x44\x45STROY\x10\x03\x12\x0b\n\x07RESTART\x10\x04*9\n\x0e\x45SyncFullStage\x12\r\n\tLogoBlobs\x10\x01\x12\n\n\x06\x42locks\x10\x02\x12\x0c\n\x08\x42\x61rriers\x10\x03*h\n\x0b\x45\x44\x62StatType\x12\x11\n\rStatLogoBlobs\x10\x01\x12\x0e\n\nStatBlocks\x10\x02\x12\x10\n\x0cStatBarriers\x10\x03\x12\x12\n\x0eStatTabletType\x10\x04\x12\x10\n\x0cStatHugeType\x10\x05*Q\n\rEDbStatAction\x12\n\n\x06\x44umpDb\x10\x01\x12\n\n\x06StatDb\x10\x02\x12\x14\n\x10StatTabletAction\x10\x03\x12\x12\n\x0eStatHugeAction\x10\x04*G\n\x0c\x45VDiskStatus\x12\t\n\x05\x45RROR\x10\x00\x12\x10\n\x0cINIT_PENDING\x10\x01\x12\x0f\n\x0bREPLICATING\x10\x02\x12\t\n\x05READY\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EVDISKQUEUEID._options = None
  _EVDISKQUEUEID._serialized_options = b'\020\001'
  _EVDISKINTERNALQUEUEID._options = None
  _EVDISKINTERNALQUEUEID._serialized_options = b'\020\001'
  _EPUTHANDLECLASS._serialized_start=28617
  _EPUTHANDLECLASS._serialized_end=28678
  _EGETHANDLECLASS._serialized_start=28680
  _EGETHANDLECLASS._serialized_end=28753
  _EVDISKQUEUEID._serialized_start=28756
  _EVDISKQUEUEID._serialized_end=28929
  _EVDISKINTERNALQUEUEID._serialized_start=28932
  _EVDISKINTERNALQUEUEID._serialized_end=29137
  _ESTATUSFLAGS._serialized_start=29140
  _ESTATUSFLAGS._serialized_end=29496
  _EENTITYSTATUS._serialized_start=29498
  _EENTITYSTATUS._serialized_end=29564
  _ESYNCFULLSTAGE._serialized_start=29566
  _ESYNCFULLSTAGE._serialized_end=29623
  _EDBSTATTYPE._serialized_start=29625
  _EDBSTATTYPE._serialized_end=29729
  _EDBSTATACTION._serialized_start=29731
  _EDBSTATACTION._serialized_end=29812
  _EVDISKSTATUS._serialized_start=29814
  _EVDISKSTATUS._serialized_end=29885
  _TMESSAGEID._serialized_start=395
  _TMESSAGEID._serialized_end=442
  _TVDISKCOSTSETTINGS._serialized_start=445
  _TVDISKCOSTSETTINGS._serialized_end=609
  _TWINDOWFEEDBACK._serialized_start=612
  _TWINDOWFEEDBACK._serialized_end=964
  _TWINDOWFEEDBACK_ESTATUS._serialized_start=849
  _TWINDOWFEEDBACK_ESTATUS._serialized_end=964
  _TEXECTIMESTATS._serialized_start=967
  _TEXECTIMESTATS._serialized_end=1132
  _TMSGQOS._serialized_start=1135
  _TMSGQOS._serialized_end=1703
  _TEVVWINDOWCHANGE._serialized_start=1706
  _TEVVWINDOWCHANGE._serialized_end=1858
  _TTIMESTAMPS._serialized_start=1861
  _TTIMESTAMPS._serialized_end=1990
  _TGROUPDECOMMITSTATUS._serialized_start=1992
  _TGROUPDECOMMITSTATUS._serialized_end=2069
  _TGROUPDECOMMITSTATUS_E._serialized_start=2016
  _TGROUPDECOMMITSTATUS_E._serialized_end=2069
  _TGROUPINFO._serialized_start=2072
  _TGROUPINFO._serialized_end=2808
  _TGROUPINFO_TFAILREALM._serialized_start=2645
  _TGROUPINFO_TFAILREALM._serialized_end=2808
  _TGROUPINFO_TFAILREALM_TFAILDOMAIN._serialized_start=2735
  _TGROUPINFO_TFAILREALM_TFAILDOMAIN._serialized_end=2808
  _TEVVPATCHSTART._serialized_start=2811
  _TEVVPATCHSTART._serialized_end=3115
  _TEVVPATCHFOUNDPARTS._serialized_start=3118
  _TEVVPATCHFOUNDPARTS._serialized_end=3568
  _TDIFFBLOCK._serialized_start=3570
  _TDIFFBLOCK._serialized_end=3614
  _TXORDIFFRECEIVER._serialized_start=3616
  _TXORDIFFRECEIVER._serialized_end=3697
  _TEVVPATCHDIFF._serialized_start=3700
  _TEVVPATCHDIFF._serialized_end=4162
  _TEVVPATCHXORDIFF._serialized_start=4165
  _TEVVPATCHXORDIFF._serialized_end=4546
  _TEVVPATCHXORDIFFRESULT._serialized_start=4549
  _TEVVPATCHXORDIFFRESULT._serialized_end=4715
  _TEVVPATCHRESULT._serialized_start=4718
  _TEVVPATCHRESULT._serialized_end=5208
  _TEVVMOVEDPATCH._serialized_start=5211
  _TEVVMOVEDPATCH._serialized_end=5632
  _TEVVMOVEDPATCHRESULT._serialized_start=5635
  _TEVVMOVEDPATCHRESULT._serialized_end=6122
  _TEVVINPLACEPATCH._serialized_start=6125
  _TEVVINPLACEPATCH._serialized_end=6548
  _TEVVINPLACEPATCHRESULT._serialized_start=6551
  _TEVVINPLACEPATCHRESULT._serialized_end=7040
  _TEVVPUT._serialized_start=7043
  _TEVVPUT._serialized_end=7529
  _TEVVPUT_TEXTRABLOCKCHECK._serialized_start=7473
  _TEVVPUT_TEXTRABLOCKCHECK._serialized_end=7529
  _TEVVPUTRESULT._serialized_start=7532
  _TEVVPUTRESULT._serialized_end=7984
  _TVMULTIPUTITEM._serialized_start=7987
  _TVMULTIPUTITEM._serialized_end=8213
  _TEVVMULTIPUT._serialized_start=8216
  _TEVVMULTIPUT._serialized_end=8554
  _TVMULTIPUTRESULTITEM._serialized_start=8557
  _TVMULTIPUTRESULTITEM._serialized_end=8758
  _TEVVMULTIPUTRESULT._serialized_start=8761
  _TEVVMULTIPUTRESULT._serialized_end=9205
  _TRANGEQUERY._serialized_start=9208
  _TRANGEQUERY._serialized_end=9337
  _TEXTREMEQUERY._serialized_start=9339
  _TEXTREMEQUERY._serialized_end=9438
  _TEVVGET._serialized_start=9441
  _TEVVGET._serialized_end=10195
  _TEVVGET_TTABLETDATA._serialized_start=10150
  _TEVVGET_TTABLETDATA._serialized_end=10195
  _TQUERYRESULT._serialized_start=10198
  _TQUERYRESULT._serialized_end=10447
  _TEVVGETRESULT._serialized_start=10450
  _TEVVGETRESULT._serialized_end=10860
  _TEVVBLOCK._serialized_start=10863
  _TEVVBLOCK._serialized_end=11050
  _TEVVBLOCKRESULT._serialized_start=11053
  _TEVVBLOCKRESULT._serialized_end=11322
  _TEVVGETBLOCK._serialized_start=11325
  _TEVVGETBLOCK._serialized_end=11475
  _TEVVGETBLOCKRESULT._serialized_start=11478
  _TEVVGETBLOCKRESULT._serialized_end=11725
  _TEVVASSIMILATE._serialized_start=11728
  _TEVVASSIMILATE._serialized_end=12015
  _TEVVASSIMILATE_TBARRIERKEY._serialized_start=11967
  _TEVVASSIMILATE_TBARRIERKEY._serialized_end=12015
  _TEVVASSIMILATERESULT._serialized_start=12018
  _TEVVASSIMILATERESULT._serialized_end=12882
  _TEVVASSIMILATERESULT_TBLOCK._serialized_start=12404
  _TEVVASSIMILATERESULT_TBLOCK._serialized_end=12457
  _TEVVASSIMILATERESULT_TBARRIER._serialized_start=12460
  _TEVVASSIMILATERESULT_TBARRIER._serialized_end=12763
  _TEVVASSIMILATERESULT_TBARRIER_TVALUE._serialized_start=12651
  _TEVVASSIMILATERESULT_TBARRIER_TVALUE._serialized_end=12763
  _TEVVASSIMILATERESULT_TBLOB._serialized_start=12765
  _TEVVASSIMILATERESULT_TBLOB._serialized_end=12882
  _TEVVTAKESNAPSHOT._serialized_start=12885
  _TEVVTAKESNAPSHOT._serialized_end=13019
  _TEVVTAKESNAPSHOTRESULT._serialized_start=13022
  _TEVVTAKESNAPSHOTRESULT._serialized_end=13158
  _TEVVRELEASESNAPSHOT._serialized_start=13160
  _TEVVRELEASESNAPSHOT._serialized_end=13274
  _TEVVRELEASESNAPSHOTRESULT._serialized_start=13277
  _TEVVRELEASESNAPSHOTRESULT._serialized_end=13416
  _TEVVCOLLECTGARBAGE._serialized_start=13419
  _TEVVCOLLECTGARBAGE._serialized_end=13804
  _TEVVCOLLECTGARBAGERESULT._serialized_start=13807
  _TEVVCOLLECTGARBAGERESULT._serialized_end=14108
  _TBARRIERKEY._serialized_start=14110
  _TBARRIERKEY._serialized_end=14228
  _TBARRIERVAL._serialized_start=14230
  _TBARRIERVAL._serialized_end=14301
  _TEVVGETBARRIER._serialized_start=14304
  _TEVVGETBARRIER._serialized_end=14573
  _TEVVGETBARRIERRESULT._serialized_start=14576
  _TEVVGETBARRIERRESULT._serialized_end=14883
  _TEVVCHECKREADINESS._serialized_start=14886
  _TEVVCHECKREADINESS._serialized_end=15074
  _TEVVCHECKREADINESSRESULT._serialized_start=15077
  _TEVVCHECKREADINESSRESULT._serialized_end=15350
  _TEVVREADYNOTIFY._serialized_start=15352
  _TEVVREADYNOTIFY._serialized_end=15369
  _TSYNCSTATE._serialized_start=15371
  _TSYNCSTATE._serialized_end=15416
  _TSYNCGUIDINFO._serialized_start=15419
  _TSYNCGUIDINFO._serialized_end=15553
  _TSYNCGUIDINFO_ESTATE._serialized_start=15507
  _TSYNCGUIDINFO_ESTATE._serialized_end=15553
  _TLOCALGUIDINFO._serialized_start=15556
  _TLOCALGUIDINFO._serialized_end=15720
  _TLOCALGUIDINFO_ESTATE._serialized_start=15666
  _TLOCALGUIDINFO_ESTATE._serialized_end=15720
  _TEVVSYNCGUID._serialized_start=15723
  _TEVVSYNCGUID._serialized_end=15918
  _TEVVSYNCGUIDRESULT._serialized_start=15921
  _TEVVSYNCGUIDRESULT._serialized_end=16085
  _TEVVSYNC._serialized_start=16088
  _TEVVSYNC._serialized_end=16281
  _TEVVSYNCRESULT._serialized_start=16284
  _TEVVSYNCRESULT._serialized_end=16636
  _TEVVSYNCRESULT_TSTAT._serialized_start=16610
  _TEVVSYNCRESULT_TSTAT._serialized_end=16636
  _TEVVSYNCFULL._serialized_start=16639
  _TEVVSYNCFULL._serialized_end=17031
  _TEVVSYNCFULLRESULT._serialized_start=17034
  _TEVVSYNCFULLRESULT._serialized_end=17423
  _THANDOFFDELLOGOBLOB._serialized_start=17425
  _THANDOFFDELLOGOBLOB._serialized_end=17506
  _THULLDBSTATUS._serialized_start=17508
  _THULLDBSTATUS._serialized_end=17542
  _TSYNCERSTATUS._serialized_start=17545
  _TSYNCERSTATUS._serialized_end=17785
  _TSYNCERSTATUS_EPHASE._serialized_start=17670
  _TSYNCERSTATUS_EPHASE._serialized_end=17785
  _TSYNCLOGSTATUS._serialized_start=17788
  _TSYNCLOGSTATUS._serialized_end=17952
  _TLOCALRECOVERYINFO._serialized_start=17955
  _TLOCALRECOVERYINFO._serialized_end=18214
  _TEVVSTATUS._serialized_start=18216
  _TEVVSTATUS._serialized_end=18301
  _TEVVSTATUSRESULT._serialized_start=18304
  _TEVVSTATUSRESULT._serialized_end=18936
  _TEVVDBSTAT._serialized_start=18939
  _TEVVDBSTAT._serialized_end=19287
  _TEVVDBSTAT_TDUMPDBCONSTRAINT._serialized_start=19233
  _TEVVDBSTAT_TDUMPDBCONSTRAINT._serialized_end=19287
  _TEVVDBSTATRESULT._serialized_start=19290
  _TEVVDBSTATRESULT._serialized_end=19511
  _TEVVCOMPACT._serialized_start=19514
  _TEVVCOMPACT._serialized_end=19815
  _TEVVCOMPACT_EOPTYPE._serialized_start=19760
  _TEVVCOMPACT_EOPTYPE._serialized_end=19815
  _TEVVCOMPACTRESULT._serialized_start=19817
  _TEVVCOMPACTRESULT._serialized_end=19927
  _TEVVDEFRAG._serialized_start=19929
  _TEVVDEFRAG._serialized_end=20028
  _TEVVDEFRAGRESULT._serialized_start=20031
  _TEVVDEFRAGRESULT._serialized_end=20266
  _TEVVBALDSYNCLOG._serialized_start=20268
  _TEVVBALDSYNCLOG._serialized_end=20358
  _TEVVBALDSYNCLOGRESULT._serialized_start=20360
  _TEVVBALDSYNCLOGRESULT._serialized_end=20474
  _TVDISKLOCATION._serialized_start=20476
  _TVDISKLOCATION._serialized_end=20565
  _TNODEWARDENSERVICESET._serialized_start=20568
  _TNODEWARDENSERVICESET._serialized_end=22468
  _TNODEWARDENSERVICESET_TPDISK._serialized_start=20915
  _TNODEWARDENSERVICESET_TPDISK._serialized_end=21325
  _TNODEWARDENSERVICESET_TVDISK._serialized_start=21328
  _TNODEWARDENSERVICESET_TVDISK._serialized_end=22033
  _TNODEWARDENSERVICESET_TVDISK_TDONOR._serialized_start=21790
  _TNODEWARDENSERVICESET_TVDISK_TDONOR._serialized_end=21904
  _TNODEWARDENSERVICESET_TVDISK_TDONORMODE._serialized_start=21906
  _TNODEWARDENSERVICESET_TVDISK_TDONORMODE._serialized_end=22033
  _TNODEWARDENSERVICESET_TREPLBROKERCONFIG._serialized_start=22036
  _TNODEWARDENSERVICESET_TREPLBROKERCONFIG._serialized_end=22468
  _TNODEWARDENSERVICESET_TREPLBROKERCONFIG_TMEDIATYPEQUOTA._serialized_start=22348
  _TNODEWARDENSERVICESET_TREPLBROKERCONFIG_TMEDIATYPEQUOTA._serialized_end=22468
  _TNODEWARDENCACHE._serialized_start=22470
  _TNODEWARDENCACHE._serialized_end=22592
  _TMOCKDEVICESCONFIG._serialized_start=22594
  _TMOCKDEVICESCONFIG._serialized_end=22663
  _TDRIVEDATA._serialized_start=22666
  _TDRIVEDATA._serialized_end=22850
  _TEVCONTROLLERREGISTERNODE._serialized_start=22853
  _TEVCONTROLLERREGISTERNODE._serialized_end=23051
  _TEVCONTROLLERUPDATENODEDRIVES._serialized_start=23053
  _TEVCONTROLLERUPDATENODEDRIVES._serialized_end=23152
  _TEVCONTROLLERNODESERVICESETUPDATE._serialized_start=23155
  _TEVCONTROLLERNODESERVICESETUPDATE._serialized_end=23532
  _TEVCONTROLLERNODESERVICESETUPDATE_TGROUPMETADATA._serialized_start=23472
  _TEVCONTROLLERNODESERVICESETUPDATE_TGROUPMETADATA._serialized_end=23532
  _TEVCONTROLLERGROUPRECONFIGUREWIPE._serialized_start=23534
  _TEVCONTROLLERGROUPRECONFIGUREWIPE._serialized_end=23622
  _TEVCONTROLLERGROUPRECONFIGUREWIPERESULT._serialized_start=23624
  _TEVCONTROLLERGROUPRECONFIGUREWIPERESULT._serialized_end=23730
  _TEVCONTROLLERCONFIGREQUEST._serialized_start=23732
  _TEVCONTROLLERCONFIGREQUEST._serialized_end=23825
  _TEVCONTROLLERCONFIGRESPONSE._serialized_start=23827
  _TEVCONTROLLERCONFIGRESPONSE._serialized_end=23917
  _TEVCONTROLLERGETGROUP._serialized_start=23919
  _TEVCONTROLLERGETGROUP._serialized_end=23976
  _TEVCONTROLLERPROPOSEGROUPKEY._serialized_start=23979
  _TEVCONTROLLERPROPOSEGROUPKEY._serialized_end=24178
  _TSTORAGEOWNERGROUPINFO._serialized_start=24180
  _TSTORAGEOWNERGROUPINFO._serialized_end=24288
  _TSTORAGEOWNERINFO._serialized_start=24290
  _TSTORAGEOWNERINFO._serialized_end=24407
  _TEVCONTROLLERSELECTGROUPS._serialized_start=24410
  _TEVCONTROLLERSELECTGROUPS._serialized_end=25059
  _TEVCONTROLLERSELECTGROUPS_TSTORAGEPOOLSPECIFIER._serialized_start=24716
  _TEVCONTROLLERSELECTGROUPS_TSTORAGEPOOLSPECIFIER._serialized_end=24767
  _TEVCONTROLLERSELECTGROUPS_TGROUPPARAMETERS._serialized_start=24770
  _TEVCONTROLLERSELECTGROUPS_TGROUPPARAMETERS._serialized_end=25047
  _TVDISKSTATUS._serialized_start=25062
  _TVDISKSTATUS._serialized_end=25242
  _TEVCONTROLLERUPDATEDISKSTATUS._serialized_start=25245
  _TEVCONTROLLERUPDATEDISKSTATUS._serialized_end=25447
  _TEVGROUPSTATREPORT._serialized_start=25450
  _TEVGROUPSTATREPORT._serialized_end=25807
  _TEVGROUPSTATREPORT_TLATENCYHISTOGRAM._serialized_start=25771
  _TEVGROUPSTATREPORT_TLATENCYHISTOGRAM._serialized_end=25807
  _TEVCONTROLLERUPDATEGROUPSTAT._serialized_start=25809
  _TEVCONTROLLERUPDATEGROUPSTAT._serialized_end=25903
  _TEVCONTROLLERSELECTGROUPSRESULT._serialized_start=25906
  _TEVCONTROLLERSELECTGROUPSRESULT._serialized_end=26803
  _TEVCONTROLLERSELECTGROUPSRESULT_TGROUPPARAMETERS._serialized_start=26130
  _TEVCONTROLLERSELECTGROUPSRESULT_TGROUPPARAMETERS._serialized_end=26695
  _TEVCONTROLLERSELECTGROUPSRESULT_TGROUPPARAMETERS_TRESOURCES._serialized_start=26580
  _TEVCONTROLLERSELECTGROUPSRESULT_TGROUPPARAMETERS_TRESOURCES._serialized_end=26689
  _TEVCONTROLLERSELECTGROUPSRESULT_TMATCHINGGROUPLIST._serialized_start=26697
  _TEVCONTROLLERSELECTGROUPSRESULT_TMATCHINGGROUPLIST._serialized_end=26803
  _TEVCONTROLLERSCRUBQUERYSTARTQUANTUM._serialized_start=26805
  _TEVCONTROLLERSCRUBQUERYSTARTQUANTUM._serialized_end=26889
  _TEVCONTROLLERSCRUBSTARTQUANTUM._serialized_start=26891
  _TEVCONTROLLERSCRUBSTARTQUANTUM._serialized_end=26985
  _TEVCONTROLLERSCRUBQUANTUMFINISHED._serialized_start=26988
  _TEVCONTROLLERSCRUBQUANTUMFINISHED._serialized_end=27117
  _TEVCONTROLLERSCRUBREPORTQUANTUMINPROGRESS._serialized_start=27119
  _TEVCONTROLLERSCRUBREPORTQUANTUMINPROGRESS._serialized_end=27209
  _TEVREQUESTBSCONTROLLERINFO._serialized_start=27211
  _TEVREQUESTBSCONTROLLERINFO._serialized_end=27256
  _TEVRESPONSEBSCONTROLLERINFO._serialized_start=27259
  _TEVRESPONSEBSCONTROLLERINFO._serialized_end=27667
  _TEVRESPONSEBSCONTROLLERINFO_TVDISKINFO._serialized_start=27374
  _TEVRESPONSEBSCONTROLLERINFO_TVDISKINFO._serialized_end=27512
  _TEVRESPONSEBSCONTROLLERINFO_TBSGROUPINFO._serialized_start=27515
  _TEVRESPONSEBSCONTROLLERINFO_TBSGROUPINFO._serialized_end=27667
  _TEVCONTROLLERNODEREPORT._serialized_start=27670
  _TEVCONTROLLERNODEREPORT._serialized_end=28061
  _TEVCONTROLLERNODEREPORT_TVDISKREPORT._serialized_start=27794
  _TEVCONTROLLERNODEREPORT_TVDISKREPORT._serialized_end=27974
  _TEVCONTROLLERNODEREPORT_EVDISKPHASE._serialized_start=27976
  _TEVCONTROLLERNODEREPORT_EVDISKPHASE._serialized_end=28061
  _TEVCONTROLLERGROUPDECOMMITTEDNOTIFY._serialized_start=28063
  _TEVCONTROLLERGROUPDECOMMITTEDNOTIFY._serialized_end=28117
  _TEVCONTROLLERGROUPDECOMMITTEDRESPONSE._serialized_start=28119
  _TEVCONTROLLERGROUPDECOMMITTEDRESPONSE._serialized_end=28223
  _TGROUPMETRICS._serialized_start=28225
  _TGROUPMETRICS._serialized_end=28352
  _TEVCONTROLLERGROUPMETRICSEXCHANGE._serialized_start=28354
  _TEVCONTROLLERGROUPMETRICSEXCHANGE._serialized_end=28469
  _TEVNODEWARDENQUERYGROUPINFO._serialized_start=28471
  _TEVNODEWARDENQUERYGROUPINFO._serialized_end=28517
  _TEVNODEWARDENGROUPINFO._serialized_start=28519
  _TEVNODEWARDENGROUPINFO._serialized_end=28615
# @@protoc_insertion_point(module_scope)
